==> haskell-special-values-0.1.0.0-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-L3E665l95bKAtOaIWPHpuq
key:                  special-values-0.1.0.0-L3E665l95bKAtOaIWPHpuq
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  69f29cd6f741235e6d8deb7c75cb6eb5
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.0.2/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-L3E665l95bKAtOaIWPHpuq
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
    scientific-0.3.7.0-GRg8FM6ZZOSA03UkddW954 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-special-values-0.1.0.0-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-3nwsuTfyG0SBAyyN3xERlm
key:                  special-values-0.1.0.0-3nwsuTfyG0SBAyyN3xERlm
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  664a6ef95ae2d1601d48d2bd84a786c2
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.0.2/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-3nwsuTfyG0SBAyyN3xERlm
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    ieee754-0.8.0-8ARR0f1c99A76lnIcdz1Si
    scientific-0.3.7.0-1l3L5iYBn9JD8GP8kLjgG7 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
